## Scaling the Application

Batman scaled his application across multiple cores for better performance. He used the following command:

<Row>
  <Col>
  </Col>
  <Col sticky>
    <CodeGroup title="Request">

      ```python {{ title: 'untyped' }}
      python3 app.py --workers=N --process=M
      ```

      ```python {{title: 'typed'}}
      python3 app.py --workers=N --process=M
      ```
    </CodeGroup>
  </Col>
</Row>

---

## What's next?

Now, Batman wanted to extend Robyn. Robyn told him about the advanced features.

- [Advanced Features](/documentation/en/api_reference/advanced_features)

